==> jc-1.4.0.tar.gz: java/util/zip/ZipFile__24ZipEntryEnumeration.h <==
// class java.util.zip.ZipFile$ZipEntryEnumeration

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d75ab930826eb376 java_util_zip_ZipFile__24ZipEntryEnumeration

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_zip_ZipFile__24ZipEntryEnumeration_H_
#define _JC_java_util_zip_ZipFile__24ZipEntryEnumeration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$sub_refs	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$sub_refs;
typedef struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$sub_nonrefs	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$sub_nonrefs;
typedef struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$refs	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$refs;
typedef struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$nonrefs	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$nonrefs;
typedef struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$object	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$object;

typedef const struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vmethods	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vmethods;
typedef const struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vtable	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vtable;
typedef const struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vtype	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vtype;

// Constructors
extern void _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$method$_init$fb346656e80483e8(_jc_env *, struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$method_info$nextElement$9b7c3789fa3ba818;

// Virtual methods structure
struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vmethods {
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$object *);
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$object *);
};

// Vtable
struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vmethods	java_util_zip_ZipFile__24ZipEntryEnumeration;
};

// Vtype
struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vtype {
	_jc_type			type;
	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$sub_refs {
	struct _jc_object	*elements;
};

// Reference instance fields (object)
struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$refs {
    _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$sub_refs	java_util_zip_ZipFile__24ZipEntryEnumeration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$sub_nonrefs	java_util_zip_ZipFile__24ZipEntryEnumeration;
};

// Object instance structure
struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$object {
	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vtype	*vtype;
	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vtype _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_ZipFile__24ZipEntryEnumeration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$class_object;

#endif	/* _JC_java_util_zip_ZipFile__24ZipEntryEnumeration_H_ */

==> jc-1.4.6.tar.gz: java/util/zip/ZipFile__24ZipEntryEnumeration.h <==
// class java.util.zip.ZipFile$ZipEntryEnumeration

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d75ab930826eb376 java_util_zip_ZipFile__24ZipEntryEnumeration

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_zip_ZipFile__24ZipEntryEnumeration_H_
#define _JC_java_util_zip_ZipFile__24ZipEntryEnumeration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$sub_refs	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$sub_refs;
typedef struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$sub_nonrefs	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$sub_nonrefs;
typedef struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$refs	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$refs;
typedef struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$nonrefs	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$nonrefs;
typedef struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$object	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$object;

typedef const struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vmethods	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vmethods;
typedef const struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vtable	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vtable;
typedef const struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vtype	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vtype;

// Constructors
extern void _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$method$_init$fb346656e80483e8(_jc_env *, struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$method_info$nextElement$9b7c3789fa3ba818;

// Virtual methods structure
struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vmethods {
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vmethods	java_util_zip_ZipFile__24ZipEntryEnumeration;
};

// Vtype
struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vtype {
	_jc_type			type;
	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$sub_refs {
	struct _jc_object	*elements;
};

// Reference instance fields (object)
struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$refs {
    _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$sub_refs	java_util_zip_ZipFile__24ZipEntryEnumeration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$sub_nonrefs	java_util_zip_ZipFile__24ZipEntryEnumeration;
};

// Object instance structure
struct _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$object {
	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vtype	*vtype;
	_jc_java_util_zip_ZipFile__24ZipEntryEnumeration$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$vtype _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_ZipFile__24ZipEntryEnumeration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_ZipFile__24ZipEntryEnumeration$class_object;

#endif	/* _JC_java_util_zip_ZipFile__24ZipEntryEnumeration_H_ */
